@@ -73,8 +73,15 @@ ev_pipe (int filedes [2])
 
   closesocket (listener);
 
+#if EV_SELECT_IS_WINSOCKET
+  filedes [0] = _open_osfhandle (sock [0], 0);
+  filedes [1] = _open_osfhandle (sock [1], 0);
+#else
+  /* when select isn't winsocket, we also expect socket, connect, accept etc.
+   * to work on fds */
   filedes [0] = sock [0];
   filedes [1] = sock [1];
+#endif
 
   return 0;
 
